@@ -1,17 +1,18 @@
 #!/usr/bin/env python
 
 """
-Unit tests for scikits.cuda.cublas
+Unit tests for skcuda.cublas
 """
 
-
-
 from unittest import main, makeSuite, TestCase, TestSuite
 
-import pycuda.autoinit
+import pycuda.driver as drv
 import pycuda.gpuarray as gpuarray
+from pycuda.tools import clear_context_caches, make_default_context
 import numpy as np
 
+drv.init()
+
 _SEPS = np.finfo(np.float32).eps
 _DEPS = np.finfo(np.float64).eps
 
@@ -27,12 +28,19 @@ def bptrs(a):
                 dtype=cublas.ctypes.c_void_p)
 
 class test_cublas(TestCase):
+    @classmethod
+    def setUpClass(cls):
+        cls.ctx = make_default_context()
+        cls.cublas_handle = cublas.cublasCreate()
+
+    @classmethod
+    def tearDownClass(cls):
+        cublas.cublasDestroy(cls.cublas_handle)
+        cls.ctx.pop()
+        clear_context_caches()
+
     def setUp(self):
         np.random.seed(23)    # For reproducible tests.
-        self.cublas_handle = cublas.cublasCreate()
-
-    def tearDown(self):
-        cublas.cublasDestroy(self.cublas_handle)
 
     # ISAMAX, IDAMAX, ICAMAX, IZAMAX
     def test_cublasIsamax(self):
@@ -632,7 +640,7 @@ class test_cublas(TestCase):
         from scipy.linalg import lu_factor
         l, m = 11, 7
         A = np.random.rand(l, m, m).astype(np.float32)
-        A = np.array([np.matrix(a)*np.matrix(a).T for a in A])
+        A = np.array([np.dot(a, a.T) for a in A])
 
         a_gpu = gpuarray.to_gpu(A)
         a_arr = bptrs(a_gpu)
@@ -652,7 +660,7 @@ class test_cublas(TestCase):
         from scipy.linalg import lu_factor
         l, m = 11, 7
         A = np.random.rand(l, m, m).astype(np.float64)
-        A = np.array([np.matrix(a)*np.matrix(a).T for a in A])
+        A = np.array([np.dot(a, a.T) for a in A])
 
         a_gpu = gpuarray.to_gpu(A)
         a_arr = bptrs(a_gpu)
@@ -670,6 +678,10 @@ class test_cublas(TestCase):
 
 
 def suite():
+    context = make_default_context()
+    device = context.get_device()
+    context.pop()
+
     s = TestSuite()
     s.addTest(test_cublas('test_cublasIsamax'))
     s.addTest(test_cublas('test_cublasIcamax'))
@@ -699,7 +711,7 @@ def suite():
     s.addTest(test_cublas('test_cublasCgemmBatched'))
     s.addTest(test_cublas('test_cublasStrsmBatched'))
     s.addTest(test_cublas('test_cublasSgetrfBatched'))
-    if misc.get_compute_capability(pycuda.autoinit.device) >= 1.3:
+    if misc.get_compute_capability(device) >= 1.3:
         s.addTest(test_cublas('test_cublasIdamax'))
         s.addTest(test_cublas('test_cublasIzamax'))
         s.addTest(test_cublas('test_cublasIdamin'))
